<?php

namespace Litecms\PortfolioCategory\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\PortfolioCategory\Models\PortfolioCategory;

class PortfolioCategoryPolicy
{

    /**
     * Determine if the given user can view the portfolio__category.
     *
     * @param UserPolicy $user
     * @param PortfolioCategory $portfolio__category
     *
     * @return bool
     */
    public function view(UserPolicy $user, PortfolioCategory $portfolio__category)
    {
        if ($user->canDo('portfolio_category.portfolio__category.view') && $user->isAdmin()) {
            return true;
        }

        return $portfolio__category->user_id == user_id() && $portfolio__category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a portfolio__category.
     *
     * @param UserPolicy $user
     * @param PortfolioCategory $portfolio__category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('portfolio_category.portfolio__category.create');
    }

    /**
     * Determine if the given user can update the given portfolio__category.
     *
     * @param UserPolicy $user
     * @param PortfolioCategory $portfolio__category
     *
     * @return bool
     */
    public function update(UserPolicy $user, PortfolioCategory $portfolio__category)
    {
        if ($user->canDo('portfolio_category.portfolio__category.edit') && $user->isAdmin()) {
            return true;
        }

        return $portfolio__category->user_id == user_id() && $portfolio__category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given portfolio__category.
     *
     * @param UserPolicy $user
     * @param PortfolioCategory $portfolio__category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, PortfolioCategory $portfolio__category)
    {
        return $portfolio__category->user_id == user_id() && $portfolio__category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given portfolio__category.
     *
     * @param UserPolicy $user
     * @param PortfolioCategory $portfolio__category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, PortfolioCategory $portfolio__category)
    {
        if ($user->canDo('portfolio_category.portfolio__category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given portfolio__category.
     *
     * @param UserPolicy $user
     * @param PortfolioCategory $portfolio__category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, PortfolioCategory $portfolio__category)
    {
        if ($user->canDo('portfolio_category.portfolio__category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
