<?php

namespace Litecms\PortfolioCategory\Providers;

use Illuminate\Support\ServiceProvider;

class PortfolioCategoryServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'portfolio_category');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'portfolio_category');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.portfolio_category', function ($app) {
            return $this->app->make('Litecms\PortfolioCategory\PortfolioCategory');
        });

                // Bind PortfolioCategory to repository
        $this->app->bind(
            'Litecms\PortfolioCategory\Interfaces\PortfolioCategoryRepositoryInterface',
            \Litecms\PortfolioCategory\Repositories\Eloquent\PortfolioCategoryRepository::class
        );

        $this->app->register(\Litecms\PortfolioCategory\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\PortfolioCategory\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.portfolio_category'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/portfolio_category.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/portfolio_category')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/portfolio_category')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
